@@ -10,8 +10,8 @@ test_that("auk_select works on ebd", {
             "scientific name", "observation count")
   f <- system.file("extdata/ebd-sample.txt", package = "auk")
   tmp <- tempfile()
-  ebd <- auk_ebd(f) %>% 
-    auk_select(select = cols, file = tmp) %>% 
+  ebd <- auk_ebd(f) |> 
+    auk_select(select = cols, file = tmp) |> 
     read_ebd(unique = FALSE)
   unlink(tmp)
   
@@ -21,7 +21,7 @@ test_that("auk_select works on ebd", {
   # raise an error
   cols <- "wrong column name"
   tmp <- tempfile()
-  expect_error(auk_ebd(f) %>% auk_select(select = cols, file = tmp))
+  expect_error(auk_ebd(f) |> auk_select(select = cols, file = tmp))
   unlink(tmp)
 })
 
@@ -31,8 +31,8 @@ test_that("auk_select works on sampling events", {
             "group_identifier", "sampling event identifier")
   f <- system.file("extdata/zerofill-ex_sampling.txt", package = "auk")
   tmp <- tempfile()
-  sampling <- auk_sampling(f) %>% 
-    auk_select(select = cols, file = tmp) %>% 
+  sampling <- auk_sampling(f) |> 
+    auk_select(select = cols, file = tmp) |> 
     read_sampling(unique = FALSE)
   unlink(tmp)
   
@@ -42,6 +42,6 @@ test_that("auk_select works on sampling events", {
   # raise an error
   cols <- "wrong column name"
   tmp <- tempfile()
-  expect_error(auk_sampling(f) %>% auk_select(select = cols, file = tmp))
+  expect_error(auk_sampling(f) |> auk_select(select = cols, file = tmp))
   unlink(tmp)
-})
\ No newline at end of file
+})
