@@ -2,7 +2,7 @@ context("auk_unique")
 library(dplyr)
 
 test_that("auk_unique removes duplicates", {
-  ebd <- system.file("extdata/zerofill-ex_ebd.txt", package = "auk") %>%
+  ebd <- system.file("extdata/zerofill-ex_ebd.txt", package = "auk") |> 
     read_ebd(unique = FALSE)
   ebd_unique <- auk_unique(ebd)
 
@@ -21,7 +21,7 @@ test_that("auk_unique removes duplicates", {
 })
 
 test_that("auk_unique removes duplicates in sampling file", {
-  ebd <- system.file("extdata/zerofill-ex_sampling.txt", package = "auk") %>%
+  ebd <- system.file("extdata/zerofill-ex_sampling.txt", package = "auk") |>
     read_sampling(unique = FALSE)
   ebd_unique <- auk_unique(ebd, checklists_only = TRUE)
 
@@ -40,16 +40,16 @@ test_that("auk_unique removes duplicates in sampling file", {
 })
 
 test_that("auk_unique combines ids correctly", {
-  ebd <- system.file("extdata/zerofill-ex_sampling.txt", package = "auk") %>%
+  ebd <- system.file("extdata/zerofill-ex_sampling.txt", package = "auk") |>
     read_sampling(unique = FALSE)
   ebd_unique <- auk_unique(ebd, checklists_only = TRUE)
   
-  ebd_g <- ebd %>% 
-    filter(!is.na(group_identifier)) %>% 
-    group_by(group_identifier) %>% 
-    arrange(sampling_event_identifier) %>% 
+  ebd_g <- ebd |> 
+    filter(!is.na(group_identifier)) |> 
+    group_by(group_identifier) |> 
+    arrange(sampling_event_identifier) |> 
     summarize(cid = paste(sampling_event_identifier, collapse = ","),
-              oid = paste(observer_id, collapse = ",")) %>% 
+              oid = paste(observer_id, collapse = ",")) |> 
     inner_join(ebd_unique, by = "group_identifier")
   
   expect_equal(ebd_g$cid, ebd_g$sampling_event_identifier)
@@ -57,9 +57,9 @@ test_that("auk_unique combines ids correctly", {
 })
 
 test_that("auk_unique throws error for invalid input", {
-  ebd <- system.file("extdata/zerofill-ex_ebd.txt", package = "auk") %>%
+  ebd <- system.file("extdata/zerofill-ex_ebd.txt", package = "auk") |>
     read_ebd(unique = FALSE)
-  sed <- system.file("extdata/zerofill-ex_sampling.txt", package = "auk") %>%
+  sed <- system.file("extdata/zerofill-ex_sampling.txt", package = "auk") |>
     read_sampling(unique = FALSE)
 
   expect_error(auk_unique(sed))
