@@ -18,17 +18,17 @@ test_that("filter_repeat_visits works", {
   expect_gte(min(occ$n_observations), 2)
   expect_lte(max(occ$n_observations), 10)
   # check closure period
-  days_bt_first_last_obs <- occ %>% 
-    group_by(site) %>% 
-    mutate(drange = as.integer(diff(range(observation_date)))) %>% 
-    pull(drange) %>% 
+  days_bt_first_last_obs <- occ |> 
+    group_by(site) |> 
+    mutate(drange = as.integer(diff(range(observation_date)))) |> 
+    pull(drange) |> 
     max()
   expect_lte(days_bt_first_last_obs, 30)
   occ_10 <- filter_repeat_visits(ebd_zf, annual_closure = FALSE, n_days = 10)
-  days_bt_first_last_obs <- occ_10 %>% 
-    group_by(site) %>% 
-    mutate(drange = as.integer(diff(range(observation_date)))) %>% 
-    pull(drange) %>% 
+  days_bt_first_last_obs <- occ_10 |> 
+    group_by(site) |> 
+    mutate(drange = as.integer(diff(range(observation_date)))) |> 
+    pull(drange) |> 
     max()
   expect_lte(days_bt_first_last_obs, 10)
   
@@ -36,15 +36,15 @@ test_that("filter_repeat_visits works", {
   occ <- filter_repeat_visits(ebd_zf, annual_closure = TRUE,
                               site_vars = "locality_id",
                               min_obs = 4, max_obs = 8)
-  closure_obs <- occ %>% 
-    count(locality_id, year = format(observation_date, "%Y")) %>% 
+  closure_obs <- occ |> 
+    count(locality_id, year = format(observation_date, "%Y")) |> 
     pull(n)
   expect_lte(max(closure_obs), 8)
   expect_gte(min(closure_obs), 4)
   
-  n_years <- occ %>% 
-    group_by(closure_id) %>% 
-    summarise(n_years = n_distinct(format(observation_date, "%Y"))) %>% 
+  n_years <- occ |> 
+    group_by(closure_id) |> 
+    summarise(n_years = n_distinct(format(observation_date, "%Y"))) |> 
     pull(n_years)
   expect_equal(max(n_years), 1)
   expect_equal(min(n_years), 1)
@@ -71,4 +71,4 @@ test_that("format_unmarked works", {
   expect_named(occ_um@obsCovs, c("effort_distance_km", "duration_minutes"))
   expect_equal(nrow(occ_um@y), n_distinct(occ$site))
   expect_equal(nrow(occ_um@y), nrow(occ_wide))
-})
\ No newline at end of file
+})
